@@ -64,7 +64,7 @@ _gdbm_get_bucket (GDBM_FILE dbf, int dir_index)
   if (dbf->bucket_cache == NULL)
     {
       if(_gdbm_init_cache(dbf, DEFAULT_CACHESIZE) == -1)
-        _gdbm_fatal(dbf, "couldn't init cache");
+        _gdbm_fatal(dbf, _("couldn't init cache"));
     }
 
   /* Is that one is not already current, we must find it. */
@@ -94,11 +94,11 @@ _gdbm_get_bucket (GDBM_FILE dbf, int dir_index)
       /* Read the bucket. */
       file_pos = __lseek (dbf, bucket_adr, L_SET);
       if (file_pos != bucket_adr)
-	_gdbm_fatal (dbf, "lseek error");
+	_gdbm_fatal (dbf, _("lseek error"));
 
       num_bytes = __read (dbf, dbf->bucket, dbf->header->bucket_size);
       if (num_bytes != dbf->header->bucket_size)
-	_gdbm_fatal (dbf, "read error");
+	_gdbm_fatal (dbf, _("read error"));
     }
 
   return;
@@ -145,7 +145,7 @@ _gdbm_split_bucket (GDBM_FILE dbf, int next_insert)
   if (dbf->bucket_cache == NULL)
     {
       if(_gdbm_init_cache(dbf, DEFAULT_CACHESIZE) == -1)
-        _gdbm_fatal(dbf, "couldn't init cache");
+        _gdbm_fatal(dbf, _("couldn't init cache"));
     }
 
   while (dbf->bucket->count == dbf->header->bucket_elems)
@@ -185,7 +185,7 @@ _gdbm_split_bucket (GDBM_FILE dbf, int next_insert)
 	  dir_size = dbf->header->dir_size * 2;
 	  dir_adr  = _gdbm_alloc (dbf, dir_size);
 	  new_dir  = (off_t *) malloc (dir_size);
-	  if (new_dir == NULL) _gdbm_fatal (dbf, "malloc error");
+	  if (new_dir == NULL) _gdbm_fatal (dbf, _("malloc error"));
 	  for (index = 0;
 	  	index < dbf->header->dir_size/sizeof (off_t); index++)
 	    {
@@ -308,10 +308,10 @@ _gdbm_write_bucket (GDBM_FILE dbf, cache_elem *ca_entry)
   
   file_pos = __lseek (dbf, ca_entry->ca_adr, L_SET);
   if (file_pos != ca_entry->ca_adr)
-    _gdbm_fatal (dbf, "lseek error");
+    _gdbm_fatal (dbf, _("lseek error"));
   num_bytes = __write (dbf, ca_entry->ca_bucket, dbf->header->bucket_size);
   if (num_bytes != dbf->header->bucket_size)
-    _gdbm_fatal (dbf, "write error");
+    _gdbm_fatal (dbf, _("write error"));
   ca_entry->ca_changed = FALSE;
   ca_entry->ca_data.hash_val = -1;
   ca_entry->ca_data.elem_loc = -1;
