@@ -24,11 +24,11 @@
 
 /* Determine our native magic number and bail if we can't. */
 #if SIZEOF_OFF_T == 4
-#define GDBM_MAGIC	GDBM_MAGIC32
+# define GDBM_MAGIC	GDBM_MAGIC32
 #elif SIZEOF_OFF_T == 8
-#define GDBM_MAGIC	GDBM_MAGIC64
+# define GDBM_MAGIC	GDBM_MAGIC64
 #else
-#error "Unsupported off_t size, contact GDBM maintainer.  What crazy system is this?!?"
+# error "Unsupported off_t size, contact GDBM maintainer.  What crazy system is this?!?"
 #endif
 
 /* Initialize dbm system.  FILE is a pointer to the file name.  If the file
@@ -145,15 +145,22 @@ gdbm_open (const char *file, int block_size, int flags, int mode,
     }
   if (dbf->desc < 0)
     {
-      free (dbf->name);
-      free (dbf);
+      SAVE_ERRNO (free (dbf->name);
+                  free (dbf));
       gdbm_errno = GDBM_FILE_OPEN_ERROR;
       return NULL;
     }
 
   /* Get the status of the file. */
-  fstat (dbf->desc, &file_stat);
-
+  if (fstat (dbf->desc, &file_stat))
+    {
+      SAVE_ERRNO (close (dbf->desc);
+		  free (dbf->name);
+		  free (dbf));
+      gdbm_errno = GDBM_FILE_STAT_ERROR;
+      return NULL;
+    }
+  
   /* Zero-length file can't be a reader... */
   if (((flags & GDBM_OPENMASK) == GDBM_READER) && (file_stat.st_size == 0))
     {
@@ -277,7 +284,7 @@ gdbm_open (const char *file, int block_size, int flags, int mode,
       num_bytes = __write (dbf, dbf->header, dbf->header->block_size);
       if (num_bytes != dbf->header->block_size)
 	{
-	  gdbm_close (dbf);
+	  SAVE_ERRNO (gdbm_close (dbf));
 	  gdbm_errno = GDBM_FILE_WRITE_ERROR;
 	  return NULL;
 	}
@@ -286,7 +293,7 @@ gdbm_open (const char *file, int block_size, int flags, int mode,
       num_bytes = __write (dbf, dbf->dir, dbf->header->dir_size);
       if (num_bytes != dbf->header->dir_size)
 	{
-	  gdbm_close (dbf);
+	  SAVE_ERRNO (gdbm_close (dbf));
 	  gdbm_errno = GDBM_FILE_WRITE_ERROR;
 	  return NULL;
 	}
@@ -295,7 +302,7 @@ gdbm_open (const char *file, int block_size, int flags, int mode,
       num_bytes = __write (dbf, dbf->bucket, dbf->header->bucket_size);
       if (num_bytes != dbf->header->bucket_size)
 	{
-	  gdbm_close (dbf);
+	  SAVE_ERRNO (gdbm_close (dbf));
 	  gdbm_errno = GDBM_FILE_WRITE_ERROR;
 	  return NULL;
 	}
@@ -316,7 +323,7 @@ gdbm_open (const char *file, int block_size, int flags, int mode,
       num_bytes = __read (dbf, &partial_header, sizeof (gdbm_file_header));
       if (num_bytes != sizeof (gdbm_file_header))
 	{
-	  gdbm_close (dbf);
+	  SAVE_ERRNO (gdbm_close (dbf));
 	  gdbm_errno = GDBM_FILE_READ_ERROR;
 	  return NULL;
 	}
@@ -356,7 +363,7 @@ gdbm_open (const char *file, int block_size, int flags, int mode,
 			  dbf->header->block_size-sizeof (gdbm_file_header));
       if (num_bytes != dbf->header->block_size-sizeof (gdbm_file_header))
 	{
-	  gdbm_close (dbf);
+	  SAVE_ERRNO (gdbm_close (dbf));
 	  gdbm_errno = GDBM_FILE_READ_ERROR;
 	  return NULL;
 	}
@@ -374,7 +381,7 @@ gdbm_open (const char *file, int block_size, int flags, int mode,
       file_pos = __lseek (dbf, dbf->header->dir, L_SET);
       if (file_pos != dbf->header->dir)
 	{
-	  gdbm_close (dbf);
+	  SAVE_ERRNO (gdbm_close (dbf));
 	  gdbm_errno = GDBM_FILE_SEEK_ERROR;
 	  return NULL;
 	}
@@ -382,7 +389,7 @@ gdbm_open (const char *file, int block_size, int flags, int mode,
       num_bytes = __read (dbf, dbf->dir, dbf->header->dir_size);
       if (num_bytes != dbf->header->dir_size)
 	{
-	  gdbm_close (dbf);
+	  SAVE_ERRNO (gdbm_close (dbf));
 	  gdbm_errno = GDBM_FILE_READ_ERROR;
 	  return NULL;
 	}
