@@ -19,70 +19,71 @@
 
 /* Include all system headers first. */
 #if HAVE_SYS_TYPES_H
-#include <sys/types.h>
+# include <sys/types.h>
 #endif
 #include <stdio.h>
 #if HAVE_SYS_FILE_H
-#include <sys/file.h>
+# include <sys/file.h>
 #endif
 #include <sys/stat.h>
 #if HAVE_STDLIB_H
-#include <stdlib.h>
+# include <stdlib.h>
 #endif
 #if HAVE_STRING_H
-#include <string.h>
+# include <string.h>
 #else
-#include <strings.h>
+# include <strings.h>
 #endif
 #if HAVE_UNISTD_H
-#include <unistd.h>
+# include <unistd.h>
 #endif
 #if HAVE_FCNTL_H
-#include <fcntl.h>
+# include <fcntl.h>
 #endif
+#include <errno.h>
 
 #ifndef SEEK_SET
-#define SEEK_SET        0
+# define SEEK_SET        0
 #endif
 
 #ifndef L_SET
-#define L_SET SEEK_SET
+# define L_SET SEEK_SET
 #endif
 
 /* Default block size.  Some systems do not have blocksize in their
    stat record. This code uses the BSD blocksize from stat. */
 
 #if HAVE_STRUCT_STAT_ST_BLKSIZE
-#define STATBLKSIZE file_stat.st_blksize
+# define STATBLKSIZE file_stat.st_blksize
 #else
-#define STATBLKSIZE 1024
+# define STATBLKSIZE 1024
 #endif
 
 /* Do we have ftruncate? */
 #if HAVE_FTRUNCATE
-#define TRUNCATE(dbf) ftruncate (dbf->desc, 0)
+# define TRUNCATE(dbf) ftruncate (dbf->desc, 0)
 #else
-#define TRUNCATE(dbf) close( open (dbf->name, O_RDWR|O_TRUNC, mode));
+# define TRUNCATE(dbf) close( open (dbf->name, O_RDWR|O_TRUNC, mode));
 #endif
 
 #ifndef STDERR_FILENO
-#define STDERR_FILENO 2
+# define STDERR_FILENO 2
 #endif
 
 /* I/O macros. */
 #if HAVE_MMAP
-#define __read(_dbf, _buf, _size)	_gdbm_mapped_read(_dbf, _buf, _size)
-#define __write(_dbf, _buf, _size)	_gdbm_mapped_write(_dbf, _buf, _size)
-#define __lseek(_dbf, _off, _whn)	_gdbm_mapped_lseek(_dbf, _off, _whn)
-#define __fsync(_dbf)			_gdbm_mapped_sync(_dbf)
+# define __read(_dbf, _buf, _size)	_gdbm_mapped_read(_dbf, _buf, _size)
+# define __write(_dbf, _buf, _size)	_gdbm_mapped_write(_dbf, _buf, _size)
+# define __lseek(_dbf, _off, _whn)	_gdbm_mapped_lseek(_dbf, _off, _whn)
+# define __fsync(_dbf)			_gdbm_mapped_sync(_dbf)
 #else
-#define __read(_dbf, _buf, _size)	read(_dbf->desc, _buf, _size)
-#define __write(_dbf, _buf, _size)	write(_dbf->desc, _buf, _size)
-#define __lseek(_dbf, _off, _whn)	lseek(_dbf->desc, _off, _whn)
-#if HAVE_FSYNC
-#define __fsync(_dbf)			fsync(_dbf->desc)
-#else
-#define __fsync(_dbf)			{ sync(); sync(); }
-#endif
+# define __read(_dbf, _buf, _size)	read(_dbf->desc, _buf, _size)
+# define __write(_dbf, _buf, _size)	write(_dbf->desc, _buf, _size)
+# define __lseek(_dbf, _off, _whn)	lseek(_dbf->desc, _off, _whn)
+# if HAVE_FSYNC
+#  define __fsync(_dbf)			fsync(_dbf->desc)
+# else
+#  define __fsync(_dbf)			{ sync(); sync(); }
+# endif
 #endif
 
