@@ -29,9 +29,12 @@
 #include <signal.h>
 #include <sys/ioctl.h>
 #ifdef HAVE_SYS_TERMIOS_H
-#include <sys/termios.h>
+# include <sys/termios.h>
 #endif
 #include <stdarg.h>
+#ifdef HAVE_LOCALE_H
+# include <locale.h>
+#endif
 
 const char *progname;                     /* Program name */
 
@@ -75,10 +78,11 @@ print_bucket (FILE *fp, hash_bucket *bucket, char *mesg)
 {
   int             index;
 
-  fprintf (fp, "******* %s **********\n\nbits = %d\ncount= %d\nHash Table:\n",
+  fprintf (fp,
+	   _("******* %s **********\n\nbits = %d\ncount= %d\nHash Table:\n"),
 	   mesg, bucket->bucket_bits, bucket->count);
   fprintf (fp,
-     "     #    hash value     key size    data size     data adr  home\n");
+	   _("     #    hash value     key size    data size     data adr  home\n"));
   for (index = 0; index < gdbm_file->header->bucket_elems; index++)
     fprintf (fp, "  %4d  %12x  %11d  %11d  %11lu %5d\n", index,
 	     bucket->h_table[index].hash_value,
@@ -88,8 +92,8 @@ print_bucket (FILE *fp, hash_bucket *bucket, char *mesg)
 	     bucket->h_table[index].hash_value %
 	     gdbm_file->header->bucket_elems);
 
-  fprintf (fp, "\nAvail count = %1d\n", bucket->av_count);
-  fprintf (fp, "Avail  adr     size\n");
+  fprintf (fp, _("\nAvail count = %1d\n"), bucket->av_count);
+  fprintf (fp, _("Avail  adr     size\n"));
   for (index = 0; index < bucket->av_count; index++)
     fprintf (fp, "%9lu%9d\n",
 	     (unsigned long) bucket->bucket_avail[index].av_adr,
@@ -113,7 +117,7 @@ _gdbm_avail_list_size (GDBM_FILE dbf, size_t min_size)
 	  + sizeof (avail_block));
   av_stk = (avail_block *) malloc (size);
   if (av_stk == NULL)
-    error (2, "Out of memory");
+    error (2, _("Out of memory"));
 
   /* Traverse the stack. */
   while (temp)
@@ -148,7 +152,7 @@ _gdbm_print_avail_list (FILE *fp, GDBM_FILE dbf)
   avail_block    *av_stk;
   
   /* Print the the header avail block.  */
-  fprintf (fp, "\nheader block\nsize  = %d\ncount = %d\n",
+  fprintf (fp, _("\nheader block\nsize  = %d\ncount = %d\n"),
 	   dbf->header->avail.size, dbf->header->avail.count);
   for (temp = 0; temp < dbf->header->avail.count; temp++)
     {
@@ -163,7 +167,7 @@ _gdbm_print_avail_list (FILE *fp, GDBM_FILE dbf)
 	  + sizeof (avail_block));
   av_stk = (avail_block *) malloc (size);
   if (av_stk == NULL)
-    error (2, "Out of memory");
+    error (2, _("Out of memory"));
 
   /* Print the stack. */
   while (temp)
@@ -181,8 +185,8 @@ _gdbm_print_avail_list (FILE *fp, GDBM_FILE dbf)
 	}
 
       /* Print the block! */
-      fprintf (fp, "\nblock = %d\nsize  = %d\ncount = %d\n", temp,
-	      av_stk->size, av_stk->count);
+      fprintf (fp, _("\nblock = %d\nsize  = %d\ncount = %d\n"), temp,
+	       av_stk->size, av_stk->count);
       for (temp = 0; temp < av_stk->count; temp++)
 	{
 	  fprintf (fp, "  %15d   %10lu \n", av_stk->av_table[temp].av_size,
@@ -201,9 +205,8 @@ _gdbm_print_bucket_cache (FILE *fp, GDBM_FILE dbf)
 
   if (dbf->bucket_cache != NULL)
     {
-      fprintf
-	(fp,
-	 "Bucket Cache (size %d):\n  Index:  Address  Changed  Data_Hash \n",
+      fprintf (fp,
+	_("Bucket Cache (size %d):\n  Index:  Address  Changed  Data_Hash \n"),
 	 dbf->cache_size);
       for (index = 0; index < dbf->cache_size; index++)
 	{
@@ -211,33 +214,33 @@ _gdbm_print_bucket_cache (FILE *fp, GDBM_FILE dbf)
 	  fprintf (fp, "  %5d:  %7lu %7s  %x\n",
 		   index,
 		   (unsigned long) dbf->bucket_cache[index].ca_adr,
-		   (changed ? "True" : "False"),
+		   (changed ? _("True") : _("False")),
 		   dbf->bucket_cache[index].ca_data.hash_val);
 	}
     }
   else
-    fprintf (fp, "Bucket cache has not been initialized.\n");
+    fprintf (fp, _("Bucket cache has not been initialized.\n"));
 }
 
 void
 usage ()
 {
-  printf ("Usage: %s OPTIONS\n", progname);
-  printf ("Test and modify a GDBM database.\n");
+  printf (_("Usage: %s OPTIONS\n"), progname);
+  printf (_("Test and modify a GDBM database.\n"));
   printf ("\n");
-  printf ("OPTIONS are:\n\n");
-  printf ("  -b SIZE            set block size\n");
-  printf ("  -c SIZE            set cache size\n");
-  printf ("  -g FILE            operate on FILE instead of `junk.gdbm'\n");
-  printf ("  -h                 print this help summary\n");
-  printf ("  -l                 disable file locking\n");
-  printf ("  -m                 disable file mmap\n");
-  printf ("  -n                 create database\n");
-  printf ("  -r                 open database in read-only mode\n");
-  printf ("  -s                 synchronize to the disk after each write\n");
-  printf ("  -v                 print program version\n");
+  printf (_("OPTIONS are:\n\n"));
+  printf (_("  -b SIZE            set block size\n"));
+  printf (_("  -c SIZE            set cache size\n"));
+  printf (_("  -g FILE            operate on FILE instead of `junk.gdbm'\n"));
+  printf (_("  -h                 print this help summary\n"));
+  printf (_("  -l                 disable file locking\n"));
+  printf (_("  -m                 disable file mmap\n"));
+  printf (_("  -n                 create database\n"));
+  printf (_("  -r                 open database in read-only mode\n"));
+  printf (_("  -s                 synchronize to the disk after each write\n"));
+  printf (_("  -v                 print program version\n"));
   printf ("\n");
-  printf ("Report bugs to <%s>.\n", PACKAGE_BUGREPORT);
+  printf (_("Report bugs to <%s>.\n"), PACKAGE_BUGREPORT);
 }
 
 void
@@ -276,7 +279,7 @@ read_from_file (const char *name, int replace)
   fp = fopen (name, "r");
   if (!fp)
     {
-      error (0, "cannot open file `%s' for reading: %s",
+      error (0, _("cannot open file `%s' for reading: %s"),
 	     name, strerror (errno));
       return;
     }
@@ -287,7 +290,7 @@ read_from_file (const char *name, int replace)
 
       if (!trimnl (buf))
 	{
-	  error (0, "%s:%d: line too long", name, line);
+	  error (0, _("%s:%d: line too long"), name, line);
 	  continue;
 	}
 
@@ -295,7 +298,7 @@ read_from_file (const char *name, int replace)
       p = strchr (buf, ' ');
       if (!p)
 	{
-	  error (0, "%s:%d: malformed line", name, line);
+	  error (0, _("%s:%d: malformed line"), name, line);
 	  continue;
 	}
 
@@ -306,7 +309,7 @@ read_from_file (const char *name, int replace)
       data.dptr = p;
       data.dsize = strlen (p) + data_z;
       if (gdbm_store (gdbm_file, key, data, flag) != 0)
-	error (0, "%d: item not inserted: %s",
+	error (0, _("%d: item not inserted: %s"),
 	       line, gdbm_strerror (gdbm_errno));
     }
   fclose (fp);
@@ -364,7 +367,10 @@ void
 count_handler (char *arg[NARGS] ARG_UNUSED, FILE *fp,
 	       void *call_data ARG_UNUSED)
 {
-  fprintf (fp, "There are %d items in the database.\n", get_record_count ());
+  int count = get_record_count ();
+  fprintf (fp, ngettext ("There is %d item in the database.\n",
+			 "There are %d items in the database.\n", count),
+	   count);
 }
 
 /* d key - delete */
@@ -378,9 +384,9 @@ delete_handler (char *arg[NARGS], FILE *fp, void *call_data ARG_UNUSED)
   if (gdbm_delete (gdbm_file, key_data) != 0)
     {
       if (gdbm_errno == GDBM_ITEM_NOT_FOUND)
-	error (0, "Item not found");
+	error (0, _("Item not found"));
       else
-	error (0, "Can't delete: %s",  gdbm_strerror (gdbm_errno));
+	error (0, _("Can't delete: %s"),  gdbm_strerror (gdbm_errno));
     }
 }
 
@@ -399,7 +405,7 @@ fetch_handler (char *arg[NARGS], FILE *fp, void *call_data ARG_UNUSED)
       free (return_data.dptr);
     }
   else
-    fprintf (stderr, "No such item found.\n");
+    fprintf (stderr, _("No such item found.\n"));
 }
 
 /* n [key] - next key */
@@ -424,7 +430,7 @@ nextkey_handler (char *arg[NARGS], FILE *fp, void *call_data ARG_UNUSED)
     }
   else
     {
-      fprintf (stderr, "No such item found.\n");
+      fprintf (stderr, _("No such item found.\n"));
       free (key_data.dptr);
       key_data.dptr = NULL;
     }
@@ -442,7 +448,7 @@ store_handler (char *arg[NARGS], FILE *fp, void *call_data ARG_UNUSED)
   data.dptr = arg[1];
   data.dsize = strlen (arg[1]) + data_z;
   if (gdbm_store (gdbm_file, key, data, GDBM_REPLACE) != 0)
-    fprintf (stderr, "Item not inserted.\n");
+    fprintf (stderr, _("Item not inserted.\n"));
 }
 
 /* 1 - begin iteration */
@@ -461,7 +467,7 @@ firstkey_handler (char *arg[NARGS], FILE *fp, void *call_data ARG_UNUSED)
       free (return_data.dptr);
     }
   else
-    fprintf (fp, "No such item found.\n");
+    fprintf (fp, _("No such item found.\n"));
 }
 
 /* 2 - continue iteration */
@@ -480,7 +486,7 @@ next_on_last_handler (char *arg[NARGS] ARG_UNUSED, FILE *fp,
       free (return_data.dptr);
     }
   else
-    fprintf (stderr, "No such item found.\n");
+    fprintf (stderr, _("No such item found.\n"));
 }
 
 /* r - reorganize */
@@ -489,9 +495,9 @@ reorganize_handler (char *arg[NARGS] ARG_UNUSED, FILE *fp ARG_UNUSED,
 		    void *call_data ARG_UNUSED)
 {
   if (gdbm_reorganize (gdbm_file))
-    fprintf (stderr, "Reorganization failed.\n");
+    fprintf (stderr, _("Reorganization failed.\n"));
   else
-    fprintf (stderr, "Reorganization succeeded.\n");
+    fprintf (stderr, _("Reorganization succeeded.\n"));
 }
 
 /* A - print available list */
@@ -523,10 +529,10 @@ void
 print_current_bucket_handler (char *arg[NARGS] ARG_UNUSED, FILE *fp,
 			      void *call_data ARG_UNUSED)
 {
-  print_bucket (fp, gdbm_file->bucket, "Current bucket");
-  fprintf (fp, "\n current directory entry = %d.\n",
+  print_bucket (fp, gdbm_file->bucket, _("Current bucket"));
+  fprintf (fp, _("\n current directory entry = %d.\n"),
 	   gdbm_file->bucket_dir);
-  fprintf (fp, " current bucket address  = %lu.\n",
+  fprintf (fp, _(" current bucket address  = %lu.\n"),
 	   (unsigned long) gdbm_file->cache_entry->ca_adr);
 }
 
@@ -537,7 +543,7 @@ getnum (int *pnum, char *arg, char **endp)
   unsigned long x = strtoul (arg, &p, 10);
   if (*p && !isspace (*p))
     {
-      printf ("not a number (stopped near %s)\n", p);
+      printf (_("not a number (stopped near %s)\n"), p);
       return 1;
     }
   while (*p && isspace (*p))
@@ -546,7 +552,7 @@ getnum (int *pnum, char *arg, char **endp)
     *endp = p;
   else if (*p)
     {
-      printf ("not a number (stopped near %s)\n", p);
+      printf (_("not a number (stopped near %s)\n"), p);
       return 1;
     }
   *pnum = x;
@@ -565,7 +571,7 @@ print_bucket_begin (char *arg[NARGS], size_t *exp_count, void **data ARG_UNUSED)
 
   if (temp >= gdbm_file->header->dir_size / 4)
     {
-      fprintf (stderr, "Not a bucket.\n");
+      fprintf (stderr, _("Not a bucket.\n"));
       return 1;
     }
   _gdbm_get_bucket (gdbm_file, temp);
@@ -590,8 +596,8 @@ print_dir_handler (char *arg[NARGS] ARG_UNUSED, FILE *out,
 {
   int i;
 
-  fprintf (out, "Hash table directory.\n");
-  fprintf (out, "  Size =  %d.  Bits = %d. \n\n",
+  fprintf (out, _("Hash table directory.\n"));
+  fprintf (out, _("  Size =  %d.  Bits = %d. \n\n"),
 	   gdbm_file->header->dir_size, gdbm_file->header->dir_bits);
   
   for (i = 0; i < gdbm_file->header->dir_size / 4; i++)
@@ -610,20 +616,20 @@ print_header_begin (char *arg[NARGS], size_t *exp_count, void **data ARG_UNUSED)
 void
 print_header_handler (char *arg[NARGS] ARG_UNUSED, FILE *fp, void *call_data)
 {
-  fprintf (fp, "\nFile Header: \n\n");
-  fprintf (fp, "  table        = %lu\n",
+  fprintf (fp, _("\nFile Header: \n\n"));
+  fprintf (fp, _("  table        = %lu\n"),
 	   (unsigned long) gdbm_file->header->dir);
-  fprintf (fp, "  table size   = %d\n", gdbm_file->header->dir_size);
-  fprintf (fp, "  table bits   = %d\n", gdbm_file->header->dir_bits);
-  fprintf (fp, "  block size   = %d\n", gdbm_file->header->block_size);
-  fprintf (fp, "  bucket elems = %d\n", gdbm_file->header->bucket_elems);
-  fprintf (fp, "  bucket size  = %d\n", gdbm_file->header->bucket_size);
-  fprintf (fp, "  header magic = %x\n", gdbm_file->header->header_magic);
-  fprintf (fp, "  next block   = %lu\n",
+  fprintf (fp, _("  table size   = %d\n"), gdbm_file->header->dir_size);
+  fprintf (fp, _("  table bits   = %d\n"), gdbm_file->header->dir_bits);
+  fprintf (fp, _("  block size   = %d\n"), gdbm_file->header->block_size);
+  fprintf (fp, _("  bucket elems = %d\n"), gdbm_file->header->bucket_elems);
+  fprintf (fp, _("  bucket size  = %d\n"), gdbm_file->header->bucket_size);
+  fprintf (fp, _("  header magic = %x\n"), gdbm_file->header->header_magic);
+  fprintf (fp, _("  next block   = %lu\n"),
 	   (unsigned long) gdbm_file->header->next_block);
-  fprintf (fp, "  avail size   = %d\n", gdbm_file->header->avail.size);
-  fprintf (fp, "  avail count  = %d\n", gdbm_file->header->avail.count);
-  fprintf (fp, "  avail nx blk = %lu\n",
+  fprintf (fp, _("  avail size   = %d\n"), gdbm_file->header->avail.size);
+  fprintf (fp, _("  avail count  = %d\n"), gdbm_file->header->avail.count);
+  fprintf (fp, _("  avail nx blk = %lu\n"),
 	   (unsigned long) gdbm_file->header->avail.next_block);
 }  
 
@@ -635,7 +641,7 @@ hash_handler (char *arg[NARGS], FILE *fp, void *call_data)
   
   key.dptr = arg[0];
   key.dsize = strlen (arg[0]) + key_z;
-  fprintf (fp, "hash value = %x. \n", _gdbm_hash (key));
+  fprintf (fp, _("hash value = %x. \n"), _gdbm_hash (key));
 }
 
 /* K - print the bucket cache */
@@ -691,7 +697,7 @@ list_handler (char *arg[NARGS] ARG_UNUSED, FILE *fp, void *call_data)
 
       data = gdbm_fetch (gdbm_file, key);
       if (!data.dptr)
-	error (0, "cannot fetch data (key %.*s)", key.dsize, key.dptr);
+	error (0, _("cannot fetch data (key %.*s)"), key.dsize, key.dptr);
       else
 	{
 	  fprintf (fp, "%.*s %.*s\n", key.dsize, key.dptr, data.dsize,
@@ -724,7 +730,7 @@ export_handler (char *arg[NARGS], FILE *fp, void *call_data ARG_UNUSED)
     flags = GDBM_NEWDB;
 
   if (gdbm_export (gdbm_file, arg[0], flags, 0600) == -1)
-    error (0, "gdbm_export failed, %s", gdbm_strerror (gdbm_errno));
+    error (0, _("gdbm_export failed, %s"), gdbm_strerror (gdbm_errno));
 }
 
 /* i file [replace] - import from a flat file */
@@ -737,17 +743,23 @@ import_handler (char *arg[NARGS], FILE *fp, void *call_data ARG_UNUSED)
     flag = GDBM_REPLACE;
 
   if (gdbm_import (gdbm_file, arg[0], flag) == -1)
-    error (0, "gdbm_import failed, %s", gdbm_strerror (gdbm_errno));
+    error (0, _("gdbm_import failed, %s"), gdbm_strerror (gdbm_errno));
 }
 
+static const char *
+boolstr(int val)
+{
+  return val ? _("yes") : _("no");
+}
+
 /* S - print current program status */
 void
 status_handler (char *arg[NARGS] ARG_UNUSED, FILE *fp,
 		void *call_data ARG_UNUSED)
 {
-  fprintf (fp, "Database file: %s\n", file_name);
-  fprintf (fp, "Zero terminated keys: %s\n", key_z ? "yes" : "no");
-  fprintf (fp, "Zero terminated data: %s\n", data_z ? "yes" : "no");
+  fprintf (fp, _("Database file: %s\n"), file_name);
+  fprintf (fp, _("Zero terminated keys: %s\n"), boolstr (key_z));
+  fprintf (fp, _("Zero terminated data: %s\n"), boolstr (data_z));
 }
 
 /* z - toggle key nul-termination */
@@ -756,7 +768,7 @@ key_z_handler (char *arg[NARGS] ARG_UNUSED, FILE *fp,
 	       void *call_data ARG_UNUSED)
 {
   key_z = !key_z;
-  fprintf (fp, "Zero terminated keys: %s\n", key_z ? "yes" : "no");
+  fprintf (fp, _("Zero terminated keys: %s\n"), boolstr (key_z));
 }
 
 /* Z - toggle data nul-termination */
@@ -765,7 +777,7 @@ data_z_handler (char *arg[NARGS] ARG_UNUSED, FILE *fp,
 		void *call_data ARG_UNUSED)
 {
   data_z = !data_z;
-  fprintf (fp, "Zero terminated data: %s\n", data_z ? "yes" : "no");
+  fprintf (fp, "Zero terminated data: %s\n", boolstr (data_z));
 }
 
 
@@ -785,60 +797,58 @@ struct command
 
 struct command command_tab[] = {
   { 'c', NULL, count_handler, NULL,
-    { NULL, NULL, }, "count (number of entries)" },
+    { NULL, NULL, }, N_("count (number of entries)") },
   { 'd', NULL, delete_handler, NULL,
-    { "key", NULL, }, "delete" },
+    { N_("key"), NULL, }, N_("delete") },
   { 'e', NULL, export_handler, NULL,
-    { "file", "[truncate]", }, "export" },
+    { N_("file"), "[truncate]", }, N_("export") },
   { 'f', NULL, fetch_handler, NULL,
-    { "key", NULL }, "fetch" },
+    { N_("key"), NULL }, N_("fetch") },
   { 'i', NULL, import_handler, NULL,
-    { "file", "[replace]", }, "import" },
+    { N_("file"), "[replace]", }, N_("import") },
   { 'l', list_begin, list_handler, NULL,
-    { NULL, NULL }, "list" },
+    { NULL, NULL }, N_("list") },
   { 'n', NULL, nextkey_handler, NULL,
-    { "[key]", NULL }, "nextkey" },
-  { 'q', NULL, quit_handler, NULL,
-    { NULL, NULL }, "quit" },
+    { N_("[key]"), NULL }, N_("nextkey") },
   { 's', NULL, store_handler, NULL,
-    { "key", "data" }, "store" },
+    { N_("key"), N_("data") }, N_("store") },
   { '1', NULL, firstkey_handler, NULL,
-    { NULL, NULL }, "firstkey" },
+    { NULL, NULL }, N_("firstkey") },
   { '2', NULL, next_on_last_handler, NULL,
     { NULL, NULL, },
-    "nextkey on last key (from n, 1 or 2)" },
+    N_("nextkey on last key (from n, 1 or 2)") },
   { '<', NULL, read_handler, NULL,
-    { "file", "[replace]" },
-    "read entries from file and store" },
+    { N_("file"), "[replace]" },
+    N_("read entries from file and store") },
   { 'r', NULL, reorganize_handler, NULL,
-    { NULL, NULL, }, "reorganize" },
+    { NULL, NULL, }, N_("reorganize") },
   { 'z', NULL, key_z_handler, NULL,
-    { NULL, NULL }, "toggle key nul-termination" },
+    { NULL, NULL }, N_("toggle key nul-termination") },
   { 'A', avail_begin, avail_handler, NULL,
-    { NULL, NULL, }, "print avail list" }, 
+    { NULL, NULL, }, N_("print avail list") }, 
   { 'B', print_bucket_begin, print_current_bucket_handler, NULL,
-    { "bucket-number", NULL, }, "print a bucket" },
+    { N_("bucket-number"), NULL, }, N_("print a bucket") },
   { 'C', print_current_bucket_begin, print_current_bucket_handler, NULL,
     { NULL, NULL, },
-    "print current bucket" },
+    N_("print current bucket") },
   { 'D', print_dir_begin, print_dir_handler, NULL,
-    { NULL, NULL, }, "print hash directory" },
+    { NULL, NULL, }, N_("print hash directory") },
   { 'F', print_header_begin , print_header_handler, NULL,
-    { NULL, NULL, }, "print file header" },
+    { NULL, NULL, }, N_("print file header") },
   { 'H', NULL, hash_handler, NULL,
-    { "key", NULL, }, "hash value of key" },
+    { N_("key"), NULL, }, N_("hash value of key") },
   { 'K', print_cache_begin, print_cache_handler, NULL,
-    { NULL, NULL, }, "print the bucket cache" },
+    { NULL, NULL, }, N_("print the bucket cache") },
   { 'S', NULL, status_handler, NULL,
-    { NULL, NULL }, "print current program status" },
+    { NULL, NULL }, N_("print current program status") },
   { 'V', NULL, print_version_handler, NULL,
-    { NULL, NULL, }, "print version of gdbm" },
+    { NULL, NULL, }, N_("print version of gdbm") },
   { 'Z', NULL, data_z_handler, NULL,
-    { NULL, NULL }, "toggle data nul-termination" },
+    { NULL, NULL }, N_("toggle data nul-termination") },
   { '?', help_begin, help_handler, NULL,
-    { NULL, NULL, }, "print this help list" },
+    { NULL, NULL, }, N_("print this help list") },
   { 'q', NULL, quit_handler, NULL,
-    { NULL, NULL, }, "quit the program" },
+    { NULL, NULL, }, N_("quit the program") },
   { 0 }
 };
 
@@ -865,11 +875,11 @@ help_handler (char *arg[NARGS], FILE *fp, void *call_data)
       int n = fprintf (fp, " %c", cmd->abbrev);
 
       for (i = 0; i < NARGS && cmd->args[i]; i++)
-	n += fprintf (fp, " %s", cmd->args[i]);
+	n += fprintf (fp, " %s", gettext (cmd->args[i]));
 
       if (n < CMDCOLS)
 	fprintf (fp, "%*.s", CMDCOLS-n, "");
-      fprintf (fp, " %s", cmd->doc);
+      fprintf (fp, " %s", gettext (cmd->doc));
       fputc ('\n', fp);
     }
 }
@@ -880,7 +890,7 @@ find_command (char *p)
   struct command *cmd;
   if (p[1])
     {
-      printf ("Multicharacter commands are not yet implemented.\n");
+      printf (_("Multicharacter commands are not yet implemented.\n"));
       return NULL;
     }
   for (cmd = command_tab; cmd->abbrev; cmd++)
@@ -931,6 +941,11 @@ main (int argc, char *argv[])
     progname++;
   else
     progname = argv[0];
+
+#ifdef HAVE_SETLOCALE
+  setlocale (LC_ALL, "");
+#endif
+  bindtextdomain (PACKAGE, LOCALEDIR);
   
   /* Argument checking. */
   if (argc == 2)
@@ -965,21 +980,21 @@ main (int argc, char *argv[])
 
       case 's':
 	if (reader)
-	  error (2, "-s is incompatible with -r");
+	  error (2, _("-s is incompatible with -r"));
 
 	flags = flags | GDBM_SYNC;
 	break;
 	
       case 'r':
 	if (newdb)
-	  error (2, "-r is incompatible with -n");
+	  error (2, _("-r is incompatible with -n"));
 
 	reader = TRUE;
 	break;
 	
       case 'n':
 	if (reader)
-	  error (2, "-n is incompatible with -r");
+	  error (2, _("-n is incompatible with -r"));
 
 	newdb = TRUE;
 	break;
@@ -1001,7 +1016,7 @@ main (int argc, char *argv[])
 	exit (0);
 	  
       default:
-	error (2, "unknown option; try `%s -h' for more info\n", progname);
+	error (2, _("unknown option; try `%s -h' for more info\n"), progname);
       }
 
   if (file_name == NULL)
@@ -1025,17 +1040,17 @@ main (int argc, char *argv[])
 	gdbm_open (file_name, block_size, GDBM_WRCREAT | flags, 00664, NULL);
     }
   if (gdbm_file == NULL)
-    error (2, "gdbm_open failed: %s", gdbm_strerror (gdbm_errno));
+    error (2, _("gdbm_open failed: %s"), gdbm_strerror (gdbm_errno));
 
   if (gdbm_setopt (gdbm_file, GDBM_CACHESIZE, &cache_size, sizeof (int)) ==
       -1)
-    error (2, "gdbm_setopt failed: %s", gdbm_strerror (gdbm_errno));
+    error (2, _("gdbm_setopt failed: %s"), gdbm_strerror (gdbm_errno));
 
   signal (SIGPIPE, SIG_IGN);
 
   /* Welcome message. */
   if (interactive)
-    printf ("\nWelcome to the gdbm test program.  Type ? for help.\n\n");
+    printf (_("\nWelcome to the gdbm test program.  Type ? for help.\n\n"));
 
   while (1)
     {
@@ -1068,8 +1083,8 @@ main (int argc, char *argv[])
       if (!cmd)
 	{
 	  error (0,
-		 interactive ? "Invalid command. Try ? for help." :
-		               "Unknown command");
+		 interactive ? _("Invalid command. Try ? for help.") :
+		               _("Unknown command"));
 	  continue;
 	}
 
@@ -1084,12 +1099,12 @@ main (int argc, char *argv[])
 		/* Optional argument */
 		break;
 	      if (!interactive)
-		error (1, "%c: not enough arguments", cmd->abbrev);
+		error (1, _("%c: not enough arguments"), cmd->abbrev);
 
 	      
 	      printf ("%s? ", arg);
 	      if (fgets (argbuf[i], sizeof argbuf[i], stdin) == NULL)
-		error (1, "unexpected eof");
+		error (1, _("unexpected eof"));
 
 	      trimnl (argbuf[i]);
 	      args[i] = argbuf[i];
@@ -1110,7 +1125,7 @@ main (int argc, char *argv[])
 	  out = popen (pager, "w");
 	  if (!out)
 	    {
-	      error (0, "cannot run pager `%s': %s", pager,
+	      error (0, _("cannot run pager `%s': %s"), pager,
 		     strerror (errno));
 	      pager = NULL;
 	    }
